@@ -120,6 +120,7 @@ def adjust_html_tags(origin: str) -> str:
     2. img 태그 내부에 class="img-fluid"를 넣는다.
     3. img 태그 전후의 불필요한 p 태그를 삭제한다.
     4. img 태크 전후에 figure 태그를 삽입한다.
+    5. 코드 블록을 표시하기 위해 <pre class=""></pre>를 <div class="callout">...</div>으로 고친다.
     """
 
     # 1. 글의 첫글자를 크게 하기 위해서 firstcharacter 클래스를 적용한다.
@@ -156,6 +157,14 @@ def adjust_html_tags(origin: str) -> str:
     inserted_str_2 = '</figure>'
     for i, match in enumerate(re.finditer(pattern, new_str)):
         new_str = new_str[:match.end()+(len(inserted_str_2)*i)] + inserted_str_2 + new_str[match.end()+(len(inserted_str_2)*i):]
+
+    # 5. 코드 블록을 표시하기 위해 <pre class=""></pre>를 <div class="callout">...</div>으로 고친다.
+    origin_n_target_tags = [
+        ['<pre class="">', '<div class="callout">'],
+        ["</pre>", "</div>"]
+    ]
+    for origin, target in origin_n_target_tags:
+        new_str = re.sub(origin, target, new_str)
     return new_str
 
 
